@@ -1,7 +1,8 @@
 package HTTP::MobileAttribute;
 use strict;
 use warnings;
-our $VERSION = '0.11.1';
+our $VERSION = '0.19_01';
+use 5.008001;
 use HTTP::MobileAttribute::Request;
 use HTTP::MobileAttribute::CarrierDetector;
 use UNIVERSAL::require;
@@ -76,6 +77,9 @@ HTTP::MobileAttribute - Yet Another HTTP::MobileAgent
   $agent->is_supported_flash();
   $agent->is_supported_gif();
 
+  # in apache2
+  my $agent = HTTP::MobileAttribute->new($r->headers_in);
+
 =head1 WARNINGS
 
 WE ARE NOW TESTING THE CONCEPT.
@@ -138,6 +142,7 @@ Daisuke Maki
     Tatsuhiko Miyagawa(original author of HTTP::MobileAgent)
     Satoshi Tanimoto
     Yoshiki Kurihara(Current mentainer of HTTP::MobileAgent)
+    ZIGUZAGU
 
 =head1 SEE ALSO
 
